@@ -256,7 +256,7 @@ def get_key_name(name):
 def clean_for_export(df):
     for c, t in df.dtypes.iteritems():
         if t.kind in 'OSUV':
-            df[c] = df[c].apply(func=str)
+            df[c] = df[c].dropna().apply(func=str)
             df[c] = df[c].str.replace('\n', '')
             df[c] = df[c].str.replace('\r', '')
             df[c] = df[c].str.replace(',','\t')
